%define anolis_release 1
Name:             ipset
Version:          7.17
Release:          %{anolis_release}%{?dist}
Summary:          Manage Linux IP sets

License:          GPLv2
URL:              https://ipset.netfilter.org
Source0:          %{url}/%{name}-%{version}.tar.bz2
Source1:          %{name}.service
Source2:          %{name}.start-stop

BuildRequires:    pkgconfig(bash-completion)
BuildRequires:    pkgconfig(libmnl) >= 1
BuildRequires:    make
BuildRequires:    libtool-ltdl-devel

# An explicit requirement is needed here, to avoid cases where a user would
# explicitly update only one of the two (e.g 'yum update ipset')
Requires:         %{name}-libs = %{version}-%{release}

%description
IP sets are a framework inside the Linux kernel since version 2.4.x, which can
be administered by the ipset utility. Depending on the type, currently an IP
set may store IP addresses, (TCP/UDP) port numbers or IP addresses with MAC
addresses in a way, which ensures lightning speed when matching an entry
against a set.

If you want to:
 - store multiple IP addresses or port numbers and match against the collection
   by iptables at one swoop;
 - dynamically update iptables rules against IP addresses or ports without
   performance penalty;
 - express complex IP address and ports based rulesets with one single iptables
   rule and benefit from the speed of IP sets
then ipset may be the proper tool for you.


%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package libs
Summary:       Shared library providing the IP sets functionality

%description libs
This package contains the libraries which provide the IP sets funcionality.


%package devel
Summary:       Development files for %{name}
Requires:      %{name}-libs = %{version}-%{release}

%description devel
This package contains the files required to develop software using the %{name}
libraries.


%package service
Summary:          %{name} service for %{name}s
Requires:         %{name} = %{version}-%{release}
BuildRequires:    systemd
Requires:         iptables-services
Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd
BuildArch:        noarch

%description service
This package provides the service %{name} that is split
out of the base package since it is not active by default.


%prep
%autosetup -p1

%build
%configure --disable-static --with-kmod=no --enable-bashcompl \
	--without-included-ltdl \
	--enable-settype-modules --with-settype-modules-list="all"
%make_build


%install
%make_install

# install systemd unit file
install -d -m 755 %{buildroot}/%{_unitdir}
install -c -m 644 %{SOURCE1} %{buildroot}/%{_unitdir}

# install supporting script
install -d -m 755 %{buildroot}%{_libexecdir}/%{name}
install -c -m 755 %{SOURCE2} %{buildroot}%{_libexecdir}/%{name}

# Create directory for configuration
mkdir -p %{buildroot}%{_sysconfdir}/%{name}

%generate_compatibility_deps

%preun
if [[ $1 -eq 0 && -n $(lsmod | grep "^xt_set ") ]]; then
    rmmod xt_set 2>/dev/null
    [[ $? -ne 0 ]] && echo Current iptables configuration requires ipsets && exit 1
fi


%post service
%systemd_post %{name}.service

%preun service
if [[ $1 -eq 0 && -n $(lsmod | grep "^xt_set ") ]]; then
    rmmod xt_set 2>/dev/null
    [[ $? -ne 0 ]] && echo Current iptables configuration requires ipsets && exit 1
fi
%systemd_preun %{name}.service

%postun service
%systemd_postun_with_restart %{name}.service


%files
%license COPYING
%{_sbindir}/%{name}
%{_sbindir}/%{name}-translate
%{_libdir}/%{name}
%{_datadir}/bash-completion/completions/ipset
%{_mandir}/man8/*
%{abidir}/%{name}-option.list
%{abidir}/ipset*.dump

%files doc
%doc ChangeLog

%files libs
%dir %{abidir}
%license COPYING
%{_libdir}/lib%{name}.so.13*
%{abidir}/lib%{name}.dump

%files devel
%{_includedir}/lib%{name}
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/lib%{name}.pc
%{_mandir}/man3/libipset.3.*

%files service
%{_unitdir}/%{name}.service
%dir %{_libexecdir}/%{name}
%attr(0755,root,root) %{_libexecdir}/%{name}/%{name}.start-stop
%dir %{_sysconfdir}/%{name}

%changelog
* Mon Jan 2 2023 Funda Wang <fundawang@yeah.net> - 7.17-1
- New version 7.17
- Build modules as shared libs rather than statically linked

* Wed Oct 26 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 7.15-3
- optimise spec file

* Thu Sep 29 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 7.15-2
- add doc package

* Thu Mar 10 2022 Mingyue Zhao <wb-zmy745940@alibaba-inc.com> - 7.15-1
- Init for Anolis OS 23
